==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/LinksFactor.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksFactorFactor;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksFactor
 */
@JsonPropertyOrder({ LinksFactor.JSON_PROPERTY_FACTOR })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksFactor implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_FACTOR = "factor";
    private LinksFactorFactor factor;

    public LinksFactor() {
    }

    public LinksFactor factor(LinksFactorFactor factor) {

        this.factor = factor;
        return this;
    }

    /**
     * Get factor
     *
     * @return factor
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksFactorFactor getFactor() {
        return factor;
    }

    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactor(LinksFactorFactor factor) {
        this.factor = factor;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksFactor linksFactor = (LinksFactor) o;
        return Objects.equals(this.factor, linksFactor.factor);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(factor);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksFactor {\n");
        sb.append("    factor: ").append(toIndentedString(factor)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/LinksFactor.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksFactorFactor;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksFactor
 */
@JsonPropertyOrder({ LinksFactor.JSON_PROPERTY_FACTOR })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksFactor implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_FACTOR = "factor";
    private LinksFactorFactor factor;

    public LinksFactor() {
    }

    public LinksFactor factor(LinksFactorFactor factor) {

        this.factor = factor;
        return this;
    }

    /**
     * Get factor
     *
     * @return factor
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksFactorFactor getFactor() {
        return factor;
    }

    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactor(LinksFactorFactor factor) {
        this.factor = factor;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksFactor linksFactor = (LinksFactor) o;
        return Objects.equals(this.factor, linksFactor.factor);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(factor);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksFactor {\n");
        sb.append("    factor: ").append(toIndentedString(factor)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
